summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qlistview_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qlistview_imp.h')
-rw-r--r--kjsembed/qtbindings/qlistview_imp.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/qtbindings/qlistview_imp.h b/kjsembed/qtbindings/qlistview_imp.h
index 22786b8d..f201c179 100644
--- a/kjsembed/qtbindings/qlistview_imp.h
+++ b/kjsembed/qtbindings/qlistview_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQListView;
+class TTQListView;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQListView;
namespace KJSEmbed {
/**
* Wrapper class for TQListView methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QListViewImp : public JSProxyImp
+class TQListViewImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -106,18 +106,18 @@ public:
Method_Last = -1
};
- QListViewImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QListViewImp();
+ TQListViewImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQListViewImp();
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQListView *toQListView( KJS::Object &object );
+ static TTQListView *toTQListView( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QListView_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListView_1( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -210,7 +210,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQListView *instance; // Temp
+ TTQListView *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQListView;
namespace KJSEmbed {
/**
- * Wrapper class for TQListView methods.
+ * Wrapper class for TTQListView methods.
*
* @author Richard Moore, rich@kde.org